@@ -23,7 +23,7 @@ def pow(x, y):
 	return n
 
 def pythagorean(a, b):
-	(a**2)+(b**2)=c2
+	a**2+b**2=c2
 	c=sqrt(c2)
 	return c
 
